package logique;
import org.xml.sax.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;
import javax.swing.text.*;
import tools.*;
/**
 * La classe Balise reprensente une balise Xml <br>
 * Il s'agit ici de la description du type de la balise (et non de la valeur reel de cette balise
 * dans le document Xml)<br>
 * Cette description implique et sa description dans la dtd et sa representation en terme d'IHM
 *  @author Gros Pierre Emmanuel
 *         <a href="mailto:gros@limsi.fr">gros@limsi.fr</a>
 * @version 6.0
 */
public class Balise implements XmlSerialisable
{
/**
 * Le nom de la balise
 */
protected String _name;
/** 
 * La balise est t'elle du type empty
 */
protected boolean _empty;
/**
 * Attribut donnant la representation graphique de la balise
 */
protected logique.Style _IhmAttribut;// le stylecourant
protected EnsembleStyle _ensemble_de_style;//
protected boolean _default;
/**
 * La liste des attributs
 */

protected Vector _liste_attribut;
int _order;
/**
 * Construit la balise <br>
 * @param     name est le nom de la balise <br>
 * @param     empty doit etre a vrai si la balise est du type vide
 */
public Balise(String name,boolean empty)
{
if (name!=null) _name=new String(name);
_empty=empty;
_IhmAttribut=new Style();
_liste_attribut=new Vector(10,10);
_default=true;
 _ensemble_de_style=new EnsembleStyle("default");
_ensemble_de_style.AddStyle("default",_IhmAttribut);
}
public Balise()
{
_default=true;
_liste_attribut=null;

}
public boolean changeStyle(String style)
{

Style wanted=getStyle(style);
boolean result=true;
 LogFile.println("Balise::changeStyle("+style+")");
if (wanted==null)
{
	 LogFile.println("Balise::changeStyle wanted null");
wanted=getStyle("default");
_default=true;
result=false;
}

_IhmAttribut=wanted;
return result;
}
public void AddStyle(String style)
{
Style wanted=getStyle("default");
 LogFile.println("Balise::AddStyle("+style+")");

_ensemble_de_style.AddStyle(style,(Style)wanted.clone());
changeStyle(style);
}
public void AddStyle(String style,Style st)
{
Style wanted=st;
 LogFile.println("Balise::AddStyle("+style+")");

_ensemble_de_style.AddStyle(style,(Style)wanted.clone());
changeStyle(style);
}

public logique.Style getStyle(String style)
{
	return _ensemble_de_style.get(style);

}
/**
 * setOder met a jour l'ordre de la balise
 * @param order l'ordre de la balise
 */
 public SemantiqueRule getRule(){return _IhmAttribut.getSemantiqueStyle();}
 public void setRule(SemantiqueRule rule){_IhmAttribut.setSemantiqueStyle(rule);}
public void setOrder(int order)
{
_order=order;
}
/**
 * renvoie l'ordre de la balise
 * @result l'ordre de la balise
 */
public int getOrder()
{
return(_order);
}
/**
 * renvoie vrai si la balise est du type vide 
 * @result vrai si la balise est vide
 */
public boolean IsEmptyBalise()
{
return _empty;
}



/**
 * Renvoie la representation graphique de la balise
 * @result le style graphique de la balise
 */
public SimpleAttributeSet getAttribut(){return _IhmAttribut.getGraphicStyle().getAttributes();}
/**
 * Renvoie le nom de la balise
 * @result le nom de la balise
 */
public String getName(){return _name;}
/** 
 * Renvoie une chaine de caractere representant la balise
 * @result une chaine de caractere 
 */
public String toString(){if (!_empty) {return new String (_name);}
		else {return new String(_name+new String("[Empty]"));}}
public void setListeAttribut(Vector b){_liste_attribut=b;}
/**
 * Renvoie la liste des attributs de la balise
 * @result un vecteur d'objet AttributDecl
 * @see       AttributDecl()
 *     
 */
public Vector getListeAttribut(){return _liste_attribut;}
/**
 * Add ajoute une declaration d'attribut a la liste des attribut de la balise
 * @param a la declaration d'un attribut
 */
public void Add(AttributDecl a)
{
_liste_attribut.add(a);
}

/**
 * met a jour le style graphique de la balise
 * @param attr le style graphique
 * @param ecrase vrai si on veut remplacer le style graphique , faux si on veut le fusionner
 */
public void UpDateAttributDefault(AttributeSet attr,boolean ecrase)
{

if (_default && ecrase) {_IhmAttribut.getGraphicStyle().getAttributes().addAttributes(attr);_default=true;}

}
/**
 * Mets a jour les attributs graphiques de la balise
 * @param attr le style graphique de la balise
 *
 */
public void UpDateAttribut(AttributeSet attr)
{


_IhmAttribut.getGraphicStyle().getAttributes().addAttributes(attr);
_default=false;
}

public String getXMLName(){return "balise";}

public void WriteXML(PrintWriter out)
{
out.print("<balise name=\""+getName()+"\">");
_IhmAttribut.WriteXML(out);
out.print("</balise>\n");
}
public void lectXML(Attributes attributes,Vector construct)
{
_name=attributes.getValue("name");
_IhmAttribut=(logique.Style)construct.get(0);
 LogFile.println(_IhmAttribut.getGraphicStyle().getAttributes());
_liste_attribut=new Vector(10,10);
_default=true;
 _ensemble_de_style=new EnsembleStyle("default");
_ensemble_de_style.AddStyle("default",_IhmAttribut);

}
}