/*
 * 01/02/2001 - 15:44:49
 *
 * SplashScreen.java - Jext Splash Screen (also a class loader)
 * Copyright (C) 2002 Gros Pierre-Emmanuel
 * Copyright (C) 2000 Romain Guy (Version de base)
 * gros@limsi.fr
 * romain.guy@jext.org
 * www.jext.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package splash;
import java.io.*;
import java.awt.*;
import java.util.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import tools.*;

public class SplashScreen extends JWindow implements Runnable
{
  // private fields
  private Thread thread;
  private boolean finished;
  private String[] classes;
  private JMyProgressBar progress;
  public static String version=" V 9.0";
  public static void centerComponent(Component compo)
  {
  	Dimension d=Toolkit.getDefaultToolkit().getScreenSize();
    compo.setLocation(new Point((d.width - compo.getSize().width) / 2,
                      (d.height - compo.getSize().height) / 2));
  }
  private String makeicon(String icon)
{
String result=new String("splash"+System.getProperty("file.separator")+icon);
return result;
}
public SplashScreen(){this(true);}
  public SplashScreen(boolean loading)
  {
    setBackground(Color.lightGray);
 /*   wav=new waveIO("splash/splash.wav");
   wav.Play();*/
    JPanel pane = new JPanel(new BorderLayout());

    pane.setFont(new Font("Monospaced", 0, 14));
    pane.add(BorderLayout.NORTH,new JLabel(new ImageIcon(makeicon("splash.jpg"))));

    progress = new JMyProgressBar(0, 100);
    progress.setStringPainted(true);
    progress.setFont(new Font("Monospaced", Font.BOLD, 9));
    progress.setString("");
    progress.setBorder(new MatteBorder(0, 1, 1, 1, Color.black));
    pane.add(BorderLayout.CENTER, progress);
    pane.add(BorderLayout.SOUTH, new JLabel("- (C) 2002 Gilles Bisson bisson@imag.fr-Gros Pierre-emmanuel gros@limsi.fr "+version));

    pane.setBorder(new EtchedBorder(EtchedBorder.RAISED));
    getContentPane().add(pane);

    pack();
if (loading){
   
      createClassesList();

      thread = new Thread(this);
      thread.setDaemon(true);
      thread.setPriority(Thread.NORM_PRIORITY);
 }
    centerComponent(this);
    
    setVisible(true);

   
  if (loading)    thread.run();
  else 
  this.addMouseListener(new MouseAdapter()
  {
  	public void mouseClicked(MouseEvent e) 
           {
           SplashScreen.this.setVisible(false);
           }

  
});

  /*  LogFile.println("WAV"+wav);
   if (wav!=null) wav.Stop();*/
  }

  // get the classes to be loaded from the file 'classlist'.

  private void createClassesList()
  {
    Vector buf = new Vector(30);
    BufferedReader in = new BufferedReader(new InputStreamReader(
                                           SplashScreen.class.getResourceAsStream("classlist")));
    String buffer;
    try
    { LogFile.println("here");
      while ((buffer = in.readLine()) != null)
        buf.addElement(buffer);
      in.close();
    } catch (IOException ioe) { LogFile.println(ioe); }

    classes = new String[buf.size()];
    buf.copyInto(classes);
    buf = null;
  }

  /**
   * Loads the classes dinamycally from the list.
   */

  public void run()
  {
    String packs = getClass().getName();
    int i = packs.lastIndexOf('.');
    if (i >= 0)
      packs = packs.substring(0, i + 1);
    else
      packs = "";

    for (i = 0; i < classes.length; i++)
    {
      String n = classes[i];
      int j = n.lastIndexOf('.');
      if (j < 0) n = packs + n;
      progress.setString(n);

      try
      {
        Class c = Class.forName(n);
      } catch(Exception e) { }
      progress.setValue(100 * (i + 1) / classes.length);
      LogFile.println(n+"is Loading");
    /*try{ Thread.sleep(5);} catch(Exception e){};*/
     }
    finished = true;
   
    setText("startup.loading");
    stop();
  }

  /**
   * Sets the current text of the progress bar but
   * only in the case the loading of classes is ended.
   */

  public void setText(String text)
  {
    if (finished)
      progress.setString(text);
  }

  /**
   * Sets the current progress value of the progress bar but
   * only in the case the loading of classes is ended.
   */

  public void setProgress(int percent)
  {
    if (finished)
      progress.setValue(percent);
  }

  /**
   * Stop the loading process.
   */

  public void stop()
  {
    thread = null;
    
  }
  
  /***************************************************************************
  Patch
     -> Memory management improvements : it may help the garbage collector.
     -> Author : Julien Ponge (julien@izforge.com)
     -> Date : 23, May 2001
  ***************************************************************************/
  public void finalize() throws Throwable
  {
    dispose();
   
    super.finalize();
    thread = null;
    classes = null;
    progress = null;
 
  }
  // End of patch
}

// End of SplashScreen.java

